@@ -4,10 +4,10 @@
 #' @export
 #' @param searchterm character; A vector of common or scientific names.
 #' @param fuzzy (logical) Whether to use fuzzy search or not (default: FALSE).
-#' @param dataTypes (character) Specifies the datatypes that will be returned. See Details for
-#' options.
-#' @param includeTree (logical) If TRUE (default: FALSE), returns a list containing information
-#' for parent taxa as well as the specified taxon.
+#' @param dataTypes (character) Specifies the datatypes that will be returned.
+#' See \code{\link{bold_search}} for options.
+#' @param includeTree (logical) If TRUE (default: FALSE), returns a list
+#' containing information for parent taxa as well as the specified taxon.
 #' @param ask logical; should get_tsn be run in interactive mode?
 #' If TRUE and more than one TSN is found for teh species, the user is asked for
 #' input. If FALSE NA is returned for multiple matches.
@@ -102,30 +102,28 @@
 #' get_boldid_("Osmia", fuzzy=TRUE, rows=1:5)
 #' get_boldid_("Osmia", fuzzy=TRUE, rows=1)
 #' get_boldid_(c("Osmi","Aga"), fuzzy=TRUE, rows = 1:3)
-#'
-#' # Curl options
-#' library("httr")
-#' get_boldid(searchterm = "Agapostemon", config=verbose())
-#' get_boldid(searchterm = "Agapostemon", config=progress())
-#'
-#' # use curl options
-#' library("httr")
-#' get_boldid("Agapostemon", config=verbose())
-#' bb <- get_boldid("Agapostemon", config=progress())
 #' }
 
-get_boldid <- function(searchterm, fuzzy = FALSE, dataTypes = 'basic', includeTree = FALSE,
-                       ask = TRUE, verbose = TRUE, rows = NA, rank = NULL,
-                       division = NULL, parent = NULL, ...)
-{
-  fun <- function(x, ask, verbose, rows)
-  {
+get_boldid <- function(searchterm, fuzzy = FALSE, dataTypes = 'basic',
+                       includeTree = FALSE, ask = TRUE, verbose = TRUE,
+                       rows = NA, rank = NULL, division = NULL,
+                       parent = NULL, ...) {
+
+  assert(ask, "logical")
+  assert(verbose, "logical")
+  assert(fuzzy, "logical")
+  assert(dataTypes, "character")
+  assert(includeTree, "logical")
+  assert(rank, "character")
+  assert(division, "character")
+  assert(parent, "character")
+
+  fun <- function(x, ask, verbose, rows) {
     direct <- FALSE
     mssg(verbose, "\nRetrieving data for taxon '", x, "'\n")
     bold_df <- bold_search(name = x, fuzzy = fuzzy,
                            dataTypes = dataTypes, includeTree = includeTree, ...)
     mm <- NROW(bold_df) > 1
-    #bold_df <- sub_rows(bold_df, rows)
 
     if (!class(bold_df) == "data.frame") {
       boldid <- NA_character_
@@ -135,10 +133,19 @@ get_boldid <- function(searchterm, fuzzy = FALSE, dataTypes = 'basic', includeTr
         boldid <- NA_character_
         att <- "not found"
       } else {
-        bold_df <- rename(bold_df, c('parentname' = 'parent', 'tax_rank' = 'rank',
-                                     'tax_division' = 'division'))
+        bold_df <- rename(bold_df, replace = c('parentname' = 'parent', 
+          'tax_rank' = 'rank', 'tax_division' = 'division'), 
+          warn_missing = FALSE
+        )
+        cols <- c("taxid","taxon","rank","division","parentid","parent")
+        to_add <- setdiff(cols, names(bold_df))
+        if (length(to_add) > 0) {
+          for (i in seq_along(to_add)) {
+            bold_df <- cbind(bold_df, setNames(list(NA_character_), to_add[i]))
+          }
+        }
 
-        bold_df <- bold_df[,c("taxid","taxon","rank","division","parentid","parent")]
+        bold_df <- bold_df[, c("taxid","taxon","rank","division","parentid","parent")]
 
         # should return NA if spec not found
         if (nrow(bold_df) == 0) {
@@ -165,31 +172,32 @@ get_boldid <- function(searchterm, fuzzy = FALSE, dataTypes = 'basic', includeTr
               att <- 'not found'
             }
           } else {
+            direct <- FALSE
             boldid <- NA_character_
             att <- 'found'
           }
         }
         # multiple matches
         if (any(
-          nrow(bold_df) > 1 & is.na(boldid) |
-          nrow(bold_df) > 1 & att == "found" & length(boldid) > 1
+          nrow(bold_df) > 1 && is.na(boldid) |
+          nrow(bold_df) > 1 && att == "found" && length(boldid) > 1
         )) {
+          names(bold_df)[grep('^taxon$', names(bold_df))] <- "target"
+
+          if (!is.null(division) || !is.null(parent) || !is.null(rank)) {
+            bold_df <- filt(bold_df, "division", division)
+            bold_df <- filt(bold_df, "parent", parent)
+            bold_df <- filt(bold_df, "rank", rank)
+          }
+
+          bold_df <- sub_rows(bold_df, rows)
+          boldid <- id <- bold_df$taxid
+          if (length(id) == 1) {
+            direct <- TRUE
+            att <- "found"
+          }
+
           if (ask) {
-            names(bold_df)[grep('^taxon$', names(bold_df))] <- "target"
-
-            if (!is.null(division) || !is.null(parent) || !is.null(rank)) {
-              bold_df <- filt(bold_df, "division", division)
-              bold_df <- filt(bold_df, "parent", parent)
-              bold_df <- filt(bold_df, "rank", rank)
-            }
-
-            bold_df <- sub_rows(bold_df, rows)
-            boldid <- id <- bold_df$taxid
-            if (length(id) == 1) {
-              direct <- TRUE
-              att <- "found"
-            }
-
             # user prompt
             bold_df <- bold_df[order(bold_df$target), ]
             rownames(bold_df) <- 1:nrow(bold_df)
@@ -215,8 +223,17 @@ get_boldid <- function(searchterm, fuzzy = FALSE, dataTypes = 'basic', includeTr
               }
             }
           } else {
-            boldid <- NA_character_
-            att <- "NA due to ask=FALSE"
+            if (length(boldid) == 1) {
+              att <- "found"
+            } else {
+              warning(
+                sprintf("More than one boldid found for taxon '%s'; refine query or set ask=TRUE",
+                        x),
+                call. = FALSE
+              )
+              boldid <- NA_character_
+              att <- 'NA due to ask=FALSE & > 1 result'
+            }
           }
         }
       }
