@@ -3,6 +3,9 @@ context("iucn_id")
 
 test_that("iucn_id returns the correct class", {
   skip_on_cran()
+  if (Sys.getenv('IUCN_REDLIST_KEY') == "") {
+    skip("No IUCN api key so test not run.")
+  }
 
   aa <- iucn_id("Branta canadensis")
   bb <- iucn_id("Panthera uncia")
@@ -19,6 +22,9 @@ test_that("iucn_id returns the correct class", {
 
 test_that("iucn_id fails well", {
   skip_on_cran()
+  if (Sys.getenv('IUCN_REDLIST_KEY') == "") {
+    skip("No IUCN api key so test not run.")
+  }
 
   expect_error(iucn_id(), "argument \"sciname\" is missing")
   expect_equal(suppressWarnings(iucn_id("foo bar")), NA)
