@@ -21,12 +21,10 @@ test_that("ncbi_get_taxon_summary behaves correctly when very large ID vector",
   skip_on_cran()
 
   # short UID's are okay at larger quantities
-  ids <- rep(4751, 1200)
+  ids <- rep(4751, 550)
   expect_is(ncbi_get_taxon_summary(id = ids), "data.frame")
 
   # but longer IDs add up of course
   ids <- rep(1430660, 1100)
-  expect_error(suppressMessages(ncbi_get_taxon_summary(id = ids)), "Request-URI Too Long")
-  expect_message(tryCatch(ncbi_get_taxon_summary(id = ids), error = function(e) e),
-                 "You may want to split your ids")
+  expect_message(ncbi_get_taxon_summary(id = ids), "splitting up")
 })
