@@ -13,16 +13,15 @@ test_that("trpicos_ping returns the correct value", {
   skip_on_cran()
 
   expect_true(tropicos_ping())
-  expect_false(tropicos_ping(503))
   expect_true(tropicos_ping("content"))
 })
 
 test_that("nbn_ping returns the correct value", {
   skip_on_cran()
 
-  # expect_true(nbn_ping())
-  # expect_false(nbn_ping(503))
-  # expect_true(nbn_ping("content"))
+  expect_true(nbn_ping())
+  expect_false(nbn_ping(503))
+  expect_true(nbn_ping("content"))
 })
 
 test_that("gbif_ping returns the correct value", {
@@ -41,13 +40,13 @@ test_that("bold_ping returns the correct value", {
   expect_true(bold_ping("content"))
 })
 
-test_that("ipni_ping returns the correct value", {
-  skip_on_cran()
-
-  expect_true(ipni_ping())
-  expect_false(ipni_ping(503))
-  expect_true(ipni_ping("content"))
-})
+# test_that("ipni_ping returns the correct value", {
+#   skip_on_cran()
+#
+#   expect_true(ipni_ping())
+#   expect_false(ipni_ping(503))
+#   expect_true(ipni_ping("content"))
+# })
 
 test_that("vascan_ping returns the correct value", {
   skip_on_cran()
